@@ -14,7 +14,7 @@ from base.ws_handler import BaseWebSocketHandler
 import logging
 from tornado.escape import json_decode, json_encode
 from document.models import COMMENT_ONLY, CAN_UPDATE_DOCUMENT, \
-    CAN_COMMUNICATE, FW_DOCUMENT_VERSION, DocumentTemplate
+    CAN_COMMUNICATE, FW_DOCUMENT_VERSION, DocumentTemplate, Document
 from usermedia.models import Image, DocumentImage, UserImage
 from user.util import get_user_avatar_url
 
@@ -563,10 +563,33 @@ class WebSocket(BaseWebSocketHandler):
         except DatabaseError as e:
             expected_msg = 'Save with update_fields did not affect any rows.'
             if str(e) == expected_msg:
-                doc_db.save()
+                cls.__insert_document(doc=doc_db)
             else:
                 raise e
 
+    @classmethod
+    def __insert_document(cls, doc: Document) -> None:
+        """
+        Purpose:
+        during plugin tests we experienced Integrity errors
+         at the end of tests.
+        This exception occurs while handling another exception,
+         so in order to have a clean tests output
+          we raise the exception in a way we don't output
+           misleading error messages related to different exceptions
+
+        :param doc: socket document model instance
+        :return: None
+        """
+        from django.db.utils import IntegrityError
+        try:
+            doc.save()
+        except IntegrityError as e:
+            raise IntegrityError(
+                'plugin test error when we try to save a doc already deleted '
+                'along with the rest of db data so it '
+                'raises an Integrity error: {}'.format(e)) from None
+
     @classmethod
     def save_all_docs(cls):
         for document_id in cls.sessions:
