@@ -8,7 +8,7 @@ export class LoginPage extends PreloginPage {
         this.socialaccount_providers = socialaccount_providers
         this.title = gettext('Login')
         this.pluginLoaders = pluginLoaders
-        this.headerLinks = settings.REGISTRATION_OPEN ? [
+        this.headerLinks = settings_REGISTRATION_OPEN ? [
             {
                 type: 'label',
                 text: gettext('New here?')
@@ -25,26 +25,26 @@ export class LoginPage extends PreloginPage {
         this.contents = `<div class="fw-login-left">
             <h1 class="fw-login-title">${gettext("Log in")}</h1>
             ${
-                settings.REGISTRATION_OPEN ?
-                    `<p>${gettext("If you are new here, please <a href='/account/sign-up/' title='Sign up'>sign up</a> or use one of the login options below to create an account.")}</p>` +
+                settings_REGISTRATION_OPEN ?
                     (
                         this.socialaccount_providers.length ?
-                        `<div class="socialaccount_ballot">
-                            <ul class="socialaccount_providers">
-                            ${
-                                this.socialaccount_providers.map(
-                                    provider => `<li>
-                                        <a title="${provider.name}" class="fw-button fw-socialaccount fw-${provider.id}"
-                                            href="${provider.login_url}">
-                                            <span class="fab fa-${provider.id}"></span>
-                                            ${gettext("Login with")} ${provider.name}
-                                        </a>
-                                    </li>`
-                                ).join('')
-                            }
-                            </ul>
-                        </div>` :
-                        ''
+                            `<p>${gettext("If you are new here, please <a href='/account/sign-up/' title='Sign up'>sign up</a> or use one of the login options below to create an account.")}</p>
+                            <div class="socialaccount_ballot">
+                                <ul class="socialaccount_providers">
+                                ${
+                                    this.socialaccount_providers.map(
+                                        provider => `<li>
+                                            <a title="${provider.name}" class="fw-button fw-socialaccount fw-${provider.id}"
+                                                href="${provider.login_url}">
+                                                <span class="fab fa-${provider.id}"></span>
+                                                ${gettext("Login with")} ${provider.name}
+                                            </a>
+                                        </li>`
+                                    ).join('')
+                                }
+                                </ul>
+                            </div>` :
+                            `<p>${gettext("If you are new here, please <a href='/account/sign-up/' title='Sign up'>sign up</a>.")}</p>`
                     )
                          :
                         ''
